<?php

namespace Assetdocs\Demotable\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Demotable\Models\Demotable;

class DemotablePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the demotable.
     *
     * @param User $user
     * @param Demotable $demotable
     *
     * @return bool
     */
    public function view(User $user, Demotable $demotable)
    {
        if ($user->canDo('demotable.demotable.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demotable->user_id;
    }

    /**
     * Determine if the given user can create a demotable.
     *
     * @param User $user
     * @param Demotable $demotable
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('demotable.demotable.create');
    }

    /**
     * Determine if the given user can update the given demotable.
     *
     * @param User $user
     * @param Demotable $demotable
     *
     * @return bool
     */
    public function update(User $user, Demotable $demotable)
    {
        if ($user->canDo('demotable.demotable.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demotable->user_id;
    }

    /**
     * Determine if the given user can delete the given demotable.
     *
     * @param User $user
     * @param Demotable $demotable
     *
     * @return bool
     */
    public function destroy(User $user, Demotable $demotable)
    {
        if ($user->canDo('demotable.demotable.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demotable->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
